; $Id: zero_padding last version: 2012/01/20 Andrea La Camera $
;
;+
; NAME:
;       zero_padding
;
; PURPOSE:
;       To enlarge the size of a 2d/3d array by using zero_padding. The final dimensions 
;       are dim1 x dim2. 3d arrays are padded slice per slice, i.e. the third dimension 
;       will not be changed. 
;
; CATEGORY:
;       utility
;
; CALLING SEQUENCE:
;       result = zero_padding(img, dim1, dim2, [value=value])
;
; INPUT:
;       img         : initial image, can be either 2D or 3D (cube of images)
;       dim1,dim2   : output dimensions (dim1xdim2)
;
; OPTIONAL INPUT:
;       value       : value of the extended boundary (default = 0)
;
; OUTPUT:
;       result      : the zero-padded image(s)
;
; ROUTINE MODIFICATION HISTORY:
;       routine written: May 2007,
;                        Andrea La Camera (DISI) [lacamera@disi.unige.it]
;       modifications  : November 2011,
;                        Andrea La Camera (DISI) [lacamera@disi.unige.it]
;                       -a few modifications
;                        January 2012,
;                        Andrea La Camera (DISI) [lacamera@disi.unige.it]
;                       -added option "value"
;-


function zero_padding, img, dim1, dim2, value=value

IF N_PARAMS() NE 3 then begin
   print, "Syntax:"
   print, "       result = zero_padding(image, N, M)"
   print, "where image is the input; N and M are the dimensions of the output"
   return, -1
endif
on_error,2

IF KEYWORD_SET(value) THEN ext_value=value ELSE ext_value=0

N=(size(img))[1]
M=(size(img))[2]
if ((size(img))[0] EQ 1) OR ((size(img))[0] GT 3) then message, "Only 2d/3d arrays"
if (dim1 LT N) OR (dim2 LT M) then message, $
    "Final dimensions must be greater than or equal to the initial dimensions."
if (size(img))[0] EQ 2 then begin
    img_zp=make_array(dim1,dim2,type=(size(img,/type)), value=ext_value)
    img_zp[floor((dim1-N)/2.),floor((dim2-M)/2.)]=img
endif else begin
    P=(size(img))[3]
    img_zp=make_array(dim1,dim2,P,type=(size(img,/type)), value=ext_value)
    for j=0,P-1 do img_zp[floor((dim1-N)/2.),floor((dim2-M)/2.),j]=img[*,*,j]
endelse


return, img_zp
end
